==> nextcloud-23.0.12p0.tgz: nextcloud/apps/viewer/l10n/ca.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Visor de fitxers senzill amb presentació de diapositives per a contingut multimèdia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Veieu les fotografies i vídeos de les darreres vacances com a les pel·lícules, feu un cop d'ull de la vostra darrera novel·la des de Nextcloud, escolliu el millor GIF de la vostra col·lecció gràcies a la previsualització dels vostres fitxers preferits i molt més!",
    "Your browser does not support audio." : "El vostre navegador no és compatible amb l'àudio.",
    "Error loading {name}" : "S'ha produït un error en carregar {name}",
    "Image saved" : "S'ha desat la imatge",
    "Error saving image" : "S'ha produït un error en desar la imatge",
    "Unsaved changes" : "Canvis sense desar",
    "Drop changes" : "Elimina els canvis",
    "Content of \"{fileName}\"" : "Contingut de \"{fileName}\"",
    "Your browser does not support videos." : "El vostre navegador web no és compatible amb els vídeos.",
    "Edit" : "Edició",
    "Open sidebar" : "Obre la barra lateral",
    "Download" : "Baixa",
    "Delete" : "Suprimeix",
    "There is no plugin available to display this file type" : "No hi ha cap connector disponible per a mostrar aquest tipus de fitxer",
    "View" : "Visualitza",
    "Name" : "Cognom",
    "Save" : "Desa",
    "Save as" : "Anomena i desa",
    "Back" : "Torna",
    "Loading …" : "Carregant …",
    "Reset" : "Restableix",
    "All changes will be lost." : "Tots els canvis es perdran.",
    "Are you sure you want to continue?" : "Esteu segur que voleu continuar?",
    "Cancel" : "Cancel·la",
    "Continue" : "Continua",
    "Undo" : "Desfés",
    "Redo" : "Refer",
    "Show original image" : "Mostra la imatge original",
    "Zoom in" : "Ampliació",
    "Zoom out" : "Allunya",
    "Toggle zoom menu" : "Commuta el menú de zoom",
    "Adjust" : "Ajusta",
    "Fine-tune" : "Afinar",
    "Filters" : "Filtres",
    "Watermark" : "Marca d'aigua",
    "Draw" : "Dibuixa",
    "Resize" : "Redimensiona",
    "Invalid image." : "Imatge no vàlida.",
    "Error while uploading the image." : "S'ha produït un error en carregar la imatge.",
    "are not images" : "no són imatges",
    "is not an image" : "no és una imatge",
    "to be uploaded" : "per ser carregat",
    "Crop" : "Retalla",
    "Original" : "Original",
    "Custom" : "Personalitzat",
    "Square" : "Quadrat",
    "Landscape" : "Apaïsat",
    "Portrait" : "Vertical",
    "Ellipse" : "El·lipse",
    "Classic TV" : "TV clàssica",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Fletxa",
    "Blur" : "Difumina",
    "Brightness" : "Brillantor",
    "Contrast" : "Contrast",
    "Un-flip X" : "Descapgira X",
    "Flip X" : "Capgira X",
    "Un-flip Y" : "Descapgira Y",
    "Flip Y" : "Capgira Y",
    "HSV" : "HSV",
    "Hue" : "Tonalitat",
    "Saturation" : "Saturació",
    "Value" : "Valor",
    "Image" : "Imatge",
    "Importing …" : "S'està important …",
    "+ Add image" : "+ Afegeix imatge",
    "Line" : "Línia",
    "Pen" : "Llapis",
    "Polygon" : "Polígon",
    "Sides" : "Cares",
    "Rectangle" : "Rectangle",
    "Corner Radius" : "Radi de la cantonada",
    "Width in pixels" : "Amplada en píxels",
    "Height in pixels" : "Alçada en píxels",
    "Toggle ratio lock" : "Commuta la relació d'aspecte",
    "Reset to original image size" : "Restableix la mida de la imatge original",
    "Rotate" : "Gira",
    "Text" : "Text",
    "Text spacing" : "Espaiat del text",
    "Text alignment" : "Alineació del text",
    "Font family" : "Família tipogràfica",
    "Size" : "Mida",
    "Letter spacing" : "Espaiat de la lletra",
    "Line height" : "Alçada de la línia",
    "Warmth" : "Calidesa",
    "+ Add watermark" : "+ Afegeix una marca d'aigua",
    "Choose watermark type" : "Trieu el tipus de marca d'aigua",
    "Upload watermark" : "Pujar marca d'aigua",
    "Add as text" : "Afegeix com a text",
    "Padding" : "Farciment",
    "Shadow" : "Ombra",
    "Horizontal" : "Horitzontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacitat",
    "Position" : "Posició",
    "Stroke" : "Traç",
    "Save image as" : "Anomena i desa la imatge",
    "Extension" : "Extensió",
    "Name is required." : "Cal el nom.",
    "Quality" : "Qualitat",
    "Saved image size (width x height)" : "Mida de la imatge desada (amplada x alçada)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Tingueu en compte que l'àrea de retall seleccionada és inferior al canvi de mida aplicat, cosa que pot provocar una disminució de la qualitat",
    "Actual size (100%)" : "Mida real (100%)",
    "Fit size" : "Ajust mida",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Vegeu les fotografies i els vídeos de les darreres vacances com en les pel·lícules, mostreu un fragment de la vostra darrera novel·la directament des del Nextcloud, escolliu el millor GIF de la vostra col·lecció gràcies a la previsualització directa dels vostres fitxers preferits i molt més!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.5.tgz: nextcloud/apps/viewer/l10n/ca.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visor",
    "Simple file viewer with slideshow for media" : "Visor de fitxers senzill amb presentació de diapositives per a contingut multimèdia",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Vegeu les fotografies i els vídeos de les darreres vacances com en les pel·lícules, mostreu un fragment de la vostra darrera novel·la directament des del Nextcloud, escolliu el millor GIF de la vostra col·lecció gràcies a la previsualització directa dels vostres fitxers preferits i molt més!",
    "Your browser does not support audio." : "El vostre navegador no és compatible amb l'àudio.",
    "Error loading {name}" : "S'ha produït un error en carregar {name}",
    "Unsaved changes" : "Canvis sense desar",
    "Your browser does not support videos." : "El vostre navegador web no és compatible amb els vídeos.",
    "Edit" : "Edita",
    "Open sidebar" : "Obre la barra lateral",
    "Download" : "Baixa",
    "Delete" : "Suprimeix",
    "There is no plugin available to display this file type" : "No hi ha cap connector disponible per a mostrar aquest tipus de fitxer",
    "View" : "Visualitza",
    "Name" : "Cognom",
    "Save" : "Desa",
    "Back" : "Torna",
    "Loading …" : "Carregant …",
    "Reset" : "Restableix",
    "Cancel" : "Cancel·la",
    "Continue" : "Continua",
    "Undo" : "Desfés",
    "Redo" : "Refer",
    "Zoom in" : "Ampliació",
    "Draw" : "Dibuixa",
    "Original" : "Original",
    "Custom" : "Personalitzat",
    "Landscape" : "Apaïsat",
    "Portrait" : "Vertical",
    "Value" : "Valor",
    "Image" : "Imatge",
    "Line" : "Línia",
    "Text" : "Text",
    "Size" : "Mida",
    "Position" : "Posició",
    "Extension" : "Extensió",
    "Name is required." : "Cal el nom.",
    "Quality" : "Qualitat"
},
"nplurals=2; plural=(n != 1);");
